@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,22 +22,24 @@ import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStreamReader;
-import java.io.Reader;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
+import java.util.List;
 import java.util.Properties;
 import java.util.Vector;
-import org.apache.tools.ant.Project;
+
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.Project;
 import org.apache.tools.ant.Task;
 import org.apache.tools.ant.filters.util.ChainReaderHelper;
+import org.apache.tools.ant.filters.util.ChainReaderHelper.ChainReader;
+import org.apache.tools.ant.types.FilterChain;
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.types.Reference;
 import org.apache.tools.ant.types.Resource;
 import org.apache.tools.ant.types.ResourceCollection;
-import org.apache.tools.ant.types.FilterChain;
 import org.apache.tools.ant.types.resources.FileResource;
 import org.apache.tools.ant.types.resources.JavaResource;
-import org.apache.tools.ant.util.FileUtils;
-import org.apache.tools.ant.util.ResourceUtils;
 
 /**
  * Load a file's contents as Ant properties.
@@ -55,13 +57,13 @@ public class LoadProperties extends Task {
     /**
      * Holds filterchains
      */
-    private final Vector filterChains = new Vector();
+    private final List<FilterChain> filterChains = new Vector<>();
 
     /**
      * Encoding to use for input; defaults to the platform's default encoding.
      */
     private String encoding = null;
-    
+
     /**
      * Prefix for loaded properties.
      */
@@ -91,8 +93,8 @@ public class LoadProperties extends Task {
      * encoding. <p>
      *
      * For a list of possible values see
-     * <a href="http://java.sun.com/j2se/1.5.0/docs/guide/intl/encoding.doc.html">
-     * http://java.sun.com/j2se/1.5.0/docs/guide/intl/encoding.doc.html
+     * <a href="https://docs.oracle.com/javase/8/docs/technotes/guides/intl/encoding.doc.html">
+     * https://docs.oracle.com/javase/8/docs/technotes/guides/intl/encoding.doc.html
      * </a>.</p>
      *
      * @param encoding The new Encoding value
@@ -146,6 +148,7 @@ public class LoadProperties extends Task {
      * Whether to apply the prefix when expanding properties on the
      * right hand side of a properties file as well.
      *
+     * @param b boolean
      * @since Ant 1.8.2
      */
     public void setPrefixValues(boolean b) {
@@ -157,6 +160,7 @@ public class LoadProperties extends Task {
      *
      * @exception BuildException if something goes wrong with the build
      */
+    @Override
     public final void execute() throws BuildException {
         //validation
         if (src == null) {
@@ -170,30 +174,21 @@ public class LoadProperties extends Task {
             }
             throw new BuildException("Source resource does not exist: " + src);
         }
-        BufferedInputStream bis = null;
-        Reader instream = null;
-        ByteArrayInputStream tis = null;
 
-        try {
-            bis = new BufferedInputStream(src.getInputStream());
-            if (encoding == null) {
-                instream = new InputStreamReader(bis);
-            } else {
-                instream = new InputStreamReader(bis, encoding);
-            }
-            ChainReaderHelper crh = new ChainReaderHelper();
-            crh.setPrimaryReader(instream);
-            crh.setFilterChains(filterChains);
-            crh.setProject(getProject());
-            instream = crh.getAssembledReader();
+        Charset charset = encoding == null ? Charset.defaultCharset() : Charset.forName(encoding);
 
-            String text = crh.readFully(instream);
+        try (ChainReader instream = new ChainReaderHelper(getProject(),
+            new InputStreamReader(new BufferedInputStream(src.getInputStream()), charset), filterChains)
+                .getAssembledReader()) {
 
-            if (text != null && text.length() != 0) {
+            String text = instream.readFully();
+
+            if (text != null && !text.isEmpty()) {
                 if (!text.endsWith("\n")) {
-                    text = text + "\n";
+                    text += "\n";
                 }
-                tis = new ByteArrayInputStream(text.getBytes(ResourceUtils.ISO_8859_1));
+                ByteArrayInputStream tis = new ByteArrayInputStream(
+                    text.getBytes(StandardCharsets.ISO_8859_1));
                 final Properties props = new Properties();
                 props.load(tis);
 
@@ -205,9 +200,6 @@ public class LoadProperties extends Task {
             }
         } catch (final IOException ioe) {
             throw new BuildException("Unable to load file: " + ioe, ioe, getLocation());
-        } finally {
-            FileUtils.close(bis);
-            FileUtils.close(tis);
         }
     }
 
@@ -216,7 +208,7 @@ public class LoadProperties extends Task {
      * @param filter the filter to add
      */
     public final void addFilterChain(FilterChain filter) {
-        filterChains.addElement(filter);
+        filterChains.add(filter);
     }
 
     /**
@@ -232,7 +224,7 @@ public class LoadProperties extends Task {
             throw new BuildException(
                     "only single-element resource collections are supported");
         }
-        src = (Resource) a.iterator().next();
+        src = a.iterator().next();
     }
 
     private synchronized JavaResource getRequiredJavaResource() {
